program DrDAQ_cnt;
{
Dynamic Library & Connection test program for Picotech Dr. DAQ datalogger.
Use Lazarus of Freepascal compiler.

This program contains only minimal set of Dr.DAQ driver library for testing.
If you want to use all its functions, please download usbDrDaqApi.pas file. There is code for all procedures offered by driver.
Pascal translation of the usbDrDaqApi.h file is located here: https://www.elso.sk/drdaq/usbDrDaqApi.pas and PicoStatus.h here: https://www.elso.sk/drdaq/PicoStatus.pas

DrDAQ info: https://www.elso.sk/drdaq

http://www.elso.sk/download/pico/Pico-DrDAQ-pmen.pdf

Get Linux / Raspberry Pi driver here: https://www.picotech.com/downloads/linux



Tested under Windows, Linux and Raspbian

Copyright © Marián Hubinský 2020

This software is licensed under the European Union Public License (EUPL) v 1.2
The license is available in the 22 official languages of the EU. The English version is included here.
Please see https://joinup.ec.europa.eu/community/eupl/og_page/eupl for official translations of the other languages.
}



{$IFDEF CPUARM}
  uses dynlibs, sysutils;
{$ELSE}
  uses dynlibs, crt;
{$ENDIF}


{$Q+}
{$R+}
{$I+}
{$OPTIMIZATION ON}

{$R *.res}


const
     {$IFDEF UNIX}
        libusbdrdaq = 'libusbdrdaq.so.2';
     {$ENDIF}

     {$ifdef WINDOWS}
        libusbdrdaq = 'USBDrDAQ.dll';
     {$endif}


type
    PICO_STATUS = dword;
    PICO_INFO = dword;
    TUsbDrDaqOpenUnit = function (var handle : int16):PICO_STATUS; stdcall;
    TUsbDrDaqCloseUnit = function (handle : int16):PICO_STATUS; stdcall;
    TUsbDrDaqGetUnitInfo = function (handle : int16; buffer : pchar; stringLength : int16; var requiredSize : int16; info : PICO_INFO):PICO_STATUS; stdcall;
    TUsbDrDaqEnableRGBLED = Function (handle : int16; enabled : int16):PICO_STATUS; stdcall;
    TUsbDrDaqSetRGBLED = Function (handle : int16; red : word; green : word; blue : word):PICO_STATUS; stdcall;


var
   UsbDrDaqLibHandle : TLibHandle = dynlibs.NilHandle;
   UsbDrDaqGetUnitInfo : TUsbDrDaqGetUnitInfo;
   UsbDrDaqCloseUnit : TUsbDrDaqCloseUnit;
   UsbDrDaqOpenUnit : TUsbDrDaqOpenUnit;
   UsbDrDaqEnableRGBLED : TUsbDrDaqEnableRGBLED;
   UsbDrDaqSetRGBLED : TUsbDrDaqSetRGBLED;

   DrDaqHahdle : int16;
   LibraryPath : string;

   Result : PICO_INFO;


procedure GetInfo;
var
   buffer : array[0..256] of char;
   info : cardinal;
   length : int16;
   result : PICO_STATUS;
begin
  for info := 0 to 48 do
  begin
    buffer[0] := #0;
    result := UsbDrDaqGetUnitInfo(DrDAQHahdle, buffer, 256, length, info);
    if result = 0 then writeln(info:4, #32, buffer);
  end;
end;

begin
  Writeln('Library & Connection test for pico DrDAQ by Marian Hubinsky (c) 2020 v0.97');
  Writeln(' 0 as output code means O.K. Compiled for ',{$I %FPCTARGETOS%}, ' ' , {$I %FPCTARGETCPU%},lineending);

  LibraryPath := libusbdrdaq;
  if paramstr(1) <> '' then
  begin
    LibraryPath := paramstr(1);
    Write('Loading library: ',LibraryPath);
    UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
  end
  else
  begin
    Write('Loading library: ',LibraryPath);
    UsbDrDaqLibHandle := LoadLibrary(LibraryPath);

    {$IFDEF UNIX}
      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := '/opt/picoscope/lib/libusbdrdaq.so.2';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;
    {$ENDIF}
    {$ifdef WINDOWS}
      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := 'C:\Program Files\Pico Technology\PicoScope6\USBDrDAQ.dll';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;

      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := 'C:\Program Files (x86)\Pico Technology\PicoScope6\USBDrDAQ.dll';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;

      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := 'C:\Program Files\Pico Technology\PicoLog 6\USBDrDAQ.dll';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;

      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := 'C:\Program Files (x86)\Pico Technology\PicoLog 6\USBDrDAQ.dll';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;

      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
       writeln(' ... Unsuccessful!');
       LibraryPath := 'C:\Program Files\Pico Technology\SDK\lib\usbdrdaq.lib';
       Write('Loading library: ',LibraryPath);
       UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;

      if UsbDrDaqLibHandle = dynlibs.NilHandle then
      begin
        writeln(' ... Unsuccessful!');
        LibraryPath := 'C:\Program Files (x86)\Pico Technology\SDK\lib\usbdrdaq.lib';
        Write('Loading library: ',LibraryPath);
        UsbDrDaqLibHandle := LoadLibrary(LibraryPath);
      end;
    {$endif}
  end;


  if UsbDrDaqLibHandle = dynlibs.NilHandle then
  begin
    Writeln;
    Writeln('Error: Unable to load library!');
    Writeln('You may try to specify library with path on the command line.');
    {$IFDEF UNIX}
      Writeln('Use: DrDAQ_cnt /opt/picoscope/lib/libusbdrdaq.so.2');
    {$ENDIF}
    {$ifdef WINDOWS}
      Writeln('Use: DrDAQ_cnt "C:\Program Files\Pico Technology\PicoLog 6\usbdrdaq.dll"');
    {$endif}
   end
  else
  begin
     writeln(' ... Loaded');

    {$IFDEF CPUARM}
    {$ELSE}
      Set8087CW(Get8087CW or $3f);
    {$ENDIF}

    UsbDrDaqCloseUnit := TUsbDrDaqCloseUnit(GetProcAddress(UsbDrDaqLibHandle,'UsbDrDaqCloseUnit'));
    if integer(UsbDrDaqCloseUnit) = 0 then Writeln('Error: ', GetLoadErrorStr)
    else
    begin
      UsbDrDaqGetUnitInfo := TUsbDrDaqGetUnitInfo(GetProcAddress(UsbDrDaqLibHandle,'UsbDrDaqGetUnitInfo'));
      if integer(UsbDrDaqGetUnitInfo) = 0 then Writeln('Proc UsbDrDaqGetUnitInfo error: '#9, GetLoadErrorStr);
      UsbDrDaqOpenUnit := TUsbDrDaqOpenUnit(GetProcAddress(UsbDrDaqLibHandle,'UsbDrDaqOpenUnit'));
      UsbDrDaqEnableRGBLED := TUsbDrDaqEnableRGBLED(GetProcAddress(UsbDrDaqLibHandle,'UsbDrDaqEnableRGBLED'));
      UsbDrDaqSetRGBLED := TUsbDrDaqSetRGBLED(GetProcAddress(UsbDrDaqLibHandle,'UsbDrDaqSetRGBLED'));

      Writeln(lineending,' Get info before open ...');
      GetInfo;
      writeln;

      Write('Openning DrDAQ ... ');
      Result := UsbDrDaqOpenUnit(DrDaqHahdle);
      if result = 0 then
      begin
        Writeln('OK');
        Writeln(lineending,' Get info after open ...');
        GetInfo;
        writeln;

        Writeln('Enable RGB LED:  ', UsbDrDaqEnableRGBLED(DrDaqHahdle,1));

        Writeln('Turn on RGB LED: ',UsbDrDaqSetRGBLED(DrDaqHahdle, 40, 40, 40));

        {$IFDEF CPUARM}
          sleep(100);
        {$ELSE}
          delay(100);
        {$ENDIF}

        UsbDrDaqSetRGBLED(DrDaqHahdle, 80, 0, 0);

        {$IFDEF CPUARM}
          sleep(100);
        {$ELSE}
          delay(100);
        {$ENDIF}

        UsbDrDaqSetRGBLED(DrDaqHahdle, 0, 80, 0);

        {$IFDEF CPUARM}
          sleep(100);
        {$ELSE}
          delay(100);
        {$ENDIF}

        UsbDrDaqSetRGBLED(DrDaqHahdle, 0, 0, 80);

        {$IFDEF CPUARM}
          sleep(100);
        {$ELSE}
          delay(100);
        {$ENDIF}

        Writeln('Close handle:    ',UsbDrDaqCloseUnit(DrDaqHahdle));
      end
      else
      begin
        if result = 3 then Writeln('Error: 3 PICO_NOT_FOUND') else Writeln('Error: ', result);
      end;

      if UsbDrDaqLibHandle <> DynLibs.NilHandle then if FreeLibrary(UsbDrDaqLibHandle) then UsbDrDaqLibHandle := DynLibs.NilHandle;
    end; //GetProcAddress UsbDrDaqCloseUnit
  end; // library loaded
end.


{ win64
0 2.0.20.1574
1 USB 1.1
2 1
3 USB DrDAQ
4 FR738/133
5 12Jan18
6 PICOPP.SYS V1.0
9 1.3.0.0
14 C:\Users\.....\lib\USBDrDAQ.dll
}

{ linux 64 bit
  0 UsbDrDaq Linux Driver, 2.0.34.2002
  1 USB 2.0
  2 1
  3 USB DrDAQ
  4 FR738/155
  5 12Jan18
  6 PICOPP.SYS V1.0
  9 1.3.0.0
 14 /opt/picoscope/lib/libusbdrdaq.so.2
}

{ raspbian 32 bit
Get info after open ...
  0 UsbDrDaq Linux Driver, 2.0.34.2002
  1 USB 2.0
  2 1
  3 USB DrDAQ
  4 FR738/155
  5 12Jan18
  6 PICOPP.SYS V1.0
  9 1.3.0.0
 14 /opt/picoscope/lib/libusbdrdaq.so
}

